pub enum Attribute {
Location,
Area,
MaxPowerConsumption,
MaxPowerExport,
Description,
Private(String),
}Variants
Location
Describes a single geographic point. Values contains 2 floats, generally representing longitude and latitude. Demand Response programs may define their own use of these fields.
Area
Describes a geographic area. Application specific data. Demand Response programs may define their own use of these fields, such as GeoJSON polygon data.
MaxPowerConsumption
The maximum consumption as a float, in kiloWatts.
MaxPowerExport
The maximum power the device can export as a float, in kiloWatts.
Description
A free-form short description of a VEN or resource.
Private(String)
An application specific privately defined attribute.