pub struct EventValuesMap {
pub value_type: EventType,
pub values: Vec<Value>,
}Expand description
Represents one or more values associated with a type. E.g. a type of PRICE contains a single float value.
Fields
value_type: EventTypeEnumerated or private string signifying the nature of values. E.G. "PRICE" indicates value is to be interpreted as a currency.
values: Vec<Value>A list of data points. Most often a singular value such as a price.