pub struct Interval {
pub id: i32,
pub interval_period: Option<IntervalPeriod>,
pub payloads: Vec<ValuesMap>,
}Expand description
An object defining a temporal window and a list of valuesMaps. if intervalPeriod present may set temporal aspects of interval or override event.intervalPeriod.
Fields
id: i32A client generated number assigned an interval object. Not a sequence number.
interval_period: Option<IntervalPeriod>Defines start and durations of intervals.
payloads: Vec<ValuesMap>A list of valuesMap objects.
Implementations