pub struct IntervalPeriod {
pub start: DateTime<Utc>,
pub duration: Option<Duration>,
pub randomize_start: Option<Duration>,
}Expand description
Defines temporal aspects of intervals.
A start of “0001-01-01” or “0001-01-01T00:00:00” may indicate ‘now’. See User Guide. A duration of “P9999Y” may indicate infinity. See User Guide. A randomizeStart indicates absolute range of client applied offset to start. See User Guide.
Fields
start: DateTime<Utc>The start time of an interval or set of intervals.
duration: Option<Duration>The duration of an interval or set of intervals.
randomize_start: Option<Duration>Indicates a randomization time that may be applied to start.
Implementations