pub struct ReportDescriptor {
pub payload_type: ReportType,
pub reading_type: Option<ReadingType>,
pub units: Option<Unit>,
pub targets: Option<Vec<Target>>,
pub aggregate: bool,
pub start_interval: i32,
pub num_intervals: i32,
pub historical: bool,
pub frequency: i32,
pub repeat: i32,
pub report_intervals: ReportIntervals,
}Expand description
An object that may be used to request a report from a VEN.
Fields
payload_type: ReportTypeRepresents the nature of values.
See enumerations in Definitions for defined string values, or use privately defined strings
reading_type: Option<ReadingType>Enumerated or private string signifying the type of reading.
units: Option<Unit>Units of measure.
targets: Option<Vec<Target>>A list of targets.
aggregate: boolTrue if report should aggregate results from all targeted resources. False if report includes results for each resource.
start_interval: i32The interval on which to generate a report. -1 indicates generate report at end of last interval.
num_intervals: i32The number of intervals to include in a report. -1 indicates that all intervals are to be included.
historical: boolTrue indicates report on intervals preceding startInterval. False indicates report on intervals following startInterval (e.g. forecast).
frequency: i32Number of intervals that elapse between reports. -1 indicates same as numIntervals.
repeat: i32Number of times to repeat report. 1 indicates generate one report. -1 indicates repeat indefinitely.
report_intervals: ReportIntervalsIndicates VEN report interval options. See User Guide.
Implementations
Sourceimpl ReportDescriptor
impl ReportDescriptor
Sourcepub fn new(payload_type: ReportType) -> Self
pub fn new(payload_type: ReportType) -> Self
An object that may be used to request a report from a VEN. See OpenADR REST User Guide for detailed description of how configure a report request.