pub struct ReportRequest {
pub event_id: EventId,
pub client_name: String,
pub report_name: Option<String>,
pub payload_descriptors: Option<Vec<ReportPayloadDescriptor>>,
pub resources: Vec<ReportResource>,
}Fields
event_id: EventIdID attribute of the event object this report is associated with.
client_name: StringUser generated identifier; may be VEN ID provisioned during program enrollment.
report_name: Option<String>User defined string for use in debugging or User Interface.
payload_descriptors: Option<Vec<ReportPayloadDescriptor>>A list of reportPayloadDescriptors.
An optional list of objects that provide context to payload types.
resources: Vec<ReportResource>A list of objects containing report data for a set of resources.
Implementations
Sourceimpl ReportRequest
impl ReportRequest
pub fn with_client_name(self, client_name: &str) -> Self
pub fn with_name(self, name: &str) -> Self
pub fn with_payload_descriptors( self, descriptors: Vec<ReportPayloadDescriptor>, ) -> Self
pub fn with_resources(self, resources: Vec<ReportResource>) -> Self