pub struct ResourceGroup {
pub id: ResourceGroupId,
pub created_date_time: DateTime<Utc>,
pub modification_date_time: DateTime<Utc>,
pub content: BlResourceGroupRequest,
}Expand description
A ResourceGroup is a grouping of nested resource groups or VEN resources, which is managed
by the Business Logic. The ResourceGroup can provide a more accurate representation of the
grid topology and how e.g. capacity bottlenecks affect downstream resources.
Fields
id: ResourceGroupIdURL safe VTN assigned object ID.
created_date_time: DateTime<Utc>datetime in ISO 8601 format
modification_date_time: DateTime<Utc>datetime in ISO 8601 format
content: BlResourceGroupRequestTrait Implementations
Sourceimpl Clone for ResourceGroup
impl Clone for ResourceGroup
Sourcefn clone(&self) -> ResourceGroup
fn clone(&self) -> ResourceGroup
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResourceGroup
impl Debug for ResourceGroup
Sourceimpl<'de> Deserialize<'de> for ResourceGroup
impl<'de> Deserialize<'de> for ResourceGroup
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ResourceGroup
impl PartialEq for ResourceGroup
Sourcefn eq(&self, other: &ResourceGroup) -> bool
fn eq(&self, other: &ResourceGroup) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ResourceGroup
impl Serialize for ResourceGroup
Sourceimpl Validate for ResourceGroup
impl Validate for ResourceGroup
Sourceimpl<'v_a> ValidateArgs<'v_a> for ResourceGroup
impl<'v_a> ValidateArgs<'v_a> for ResourceGroup
impl StructuralPartialEq for ResourceGroup