pub struct SubscriptionRequest {
pub client_name: String,
pub program_id: Option<ProgramId>,
pub object_operations: Vec<SubscriptionObjectOperation>,
}Expand description
An object created by a client to receive notification of operations on objects. Clients may subscribe to be notified when a type of object is created, updated, or deleted.
Fields
client_name: StringUser generated identifier, may be VEN identifier provisioned out-of-band.
program_id: Option<ProgramId>ID attribute of the program object this subscription is associated with.
object_operations: Vec<SubscriptionObjectOperation>list of objects and operations to subscribe to.