pub enum TargetType {
PowerServiceLocation,
ServiceArea,
Group,
ResourceName,
VENName,
EventName,
ProgramName,
Private(String),
}Variants
PowerServiceLocation
A Power Service Location is a utility named specific location in geography or the distribution system, usually the point of service to a customer site.
ServiceArea
A Service Area is a utility named geographic region.
Group
Targeting a specific group (string).
ResourceName
Targeting a specific resource (string).
VENName
Targeting a specific VEN (string).
EventName
Targeting a specific event (string).
ProgramName
Targeting a specific program (string).
Private(String)
An application specific privately defined target.
Implementations