pub struct ValuesMap {
pub value_type: ValueType,
pub values: Vec<Value>,
}Expand description
ValuesMap : Represents one or more values associated with a type.
See enumerations in Definitions for defined string values, or use privately defined strings
Fields
value_type: ValueTypeRepresents the nature of values.
See enumerations in Definitions for defined string values, or use privately defined strings
values: Vec<Value>A list of data points. Most often a singular value such as a price.