pub enum DataQuality {
Ok,
Missing,
Estimated,
Bad,
Private(String),
}Variants
Ok
No known reasons to doubt the data.
Missing
The data item is currently unavailable.
Estimated
The data item has been estimated from other available information.
Bad
The data item is suspected to be bad or is known to be.
Private(String)
An application specific privately defined data quality setting.