pub struct Event {
pub id: EventId,
pub created_date_time: DateTime<Utc>,
pub modification_date_time: DateTime<Utc>,
pub content: EventContent,
}Expand description
Event object to communicate a Demand Response request to VEN. If intervalPeriod is present, sets start time and duration of intervals.
Fields
id: EventIdURL safe VTN assigned object ID.
created_date_time: DateTime<Utc>datetime in ISO 8601 format
modification_date_time: DateTime<Utc>datetime in ISO 8601 format
content: EventContentTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Event
impl<'de> Deserialize<'de> for Event
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'v_a> ValidateArgs<'v_a> for Event
impl<'v_a> ValidateArgs<'v_a> for Event
impl StructuralPartialEq for Event