pub struct EventPayloadDescriptor {
pub payload_type: EventType,
pub units: Option<Unit>,
pub currency: Option<Currency>,
}Expand description
Contextual information used to interpret event valuesMap values. E.g. a PRICE payload simply contains a price value, an associated descriptor provides necessary context such as units and currency.
Fields
payload_type: EventTypeEnumerated or private string signifying the nature of values.
units: Option<Unit>Units of measure.
currency: Option<Currency>Currency of price payload.
Implementations