pub struct ReportPayloadDescriptor {
pub payload_type: ReportType,
pub reading_type: ReadingType,
pub units: Option<Unit>,
pub accuracy: Option<f32>,
pub confidence: Option<Confidence>,
}Expand description
Contextual information used to interpret report payload values. E.g. a USAGE payload simply contains a usage value, an associated descriptor provides necessary context such as units and data quality.
Fields
payload_type: ReportTypeEnumerated or private string signifying the nature of values.
reading_type: ReadingTypeEnumerated or private string signifying the type of reading.
units: Option<Unit>Units of measure.
accuracy: Option<f32>A quantification of the accuracy of a set of payload values.
confidence: Option<Confidence>A quantification of the confidence in a set of payload values.
Implementations
Sourceimpl ReportPayloadDescriptor
impl ReportPayloadDescriptor
pub fn new(payload_type: ReportType) -> Self