pub struct Notification {
pub id: Identifier,
pub operation: Operation,
pub object: AnyObject,
}Expand description
VTN generated object included in request to subscription callbackUrl.
Fields
id: IdentifierA unique ID of the operation that triggered this notification. Used to acknowledge receiving a notification over websockets and to allow a VEN to deduplicate notifications. A duplication could happend due to multiple subscriptions of (partly) overlying operations, possibly over different notification mechanisms, or if a webhook call returns an error code and gets therefore retried, for example.
Note that this an ID of the operation (create, update, …) that triggerd this notification. This means, multiple subscribers can get the same ID, possibly over different notification channels (webhook, websocket, MQTT).
The exact structure of this ID is up to the implementation, but using a counter or UUID is RECOMMENDED.
operation: Operationthe operation on on object that triggered the notification.
object: AnyObjectthe object that is the subject of the notification.